@@ -6,3 +6,6 @@ from django.contrib.sites.models import Site
 class PiwikSite(models.Model):
     id_site = models.IntegerField()
     site = models.ForeignKey(Site, unique=True)
+
+    def __unicode__(self):
+        return 'Site %s' % self.id_site
